WineBox - Wine Cellar Management

## Welcome to WineBox

Sign in to manage your wine cellar

Username
Password

## Dashboard

-
Total Bottles
-
Unique Wines
-
Wines Tracked

### By Country

### By Grape Variety

### By Vintage

### Recent Activity

## Check In Wine

### Label Images

Front Label (Required)
Tap to take photo or select image
Back Label (Optional)
Tap to take photo or select image

### Wine Details

Leave fields blank to use OCR-detected values

Wine Name
Winery
Vintage
Grape Variety
Region
Country
Alcohol %
Quantity (Bottles)
Notes

### Raw Label Text

+
Front Label OCR:

Back Label OCR:

## My Cellar

×

## Transaction History

## Search Wines

Text Search
Vintage
Grape Variety
Winery
Region
Country
In Stock Only
×

### Check Out Wine

Quantity
Notes
×
✓

### Wine Checked In Successfully

####

##### Extracted Label Text

Front Label:

Back Label: